@@ -1,6 +1,5 @@
 """Top-level package for cloudtipsadp API Python Client Library."""
-from cloudtipsadp.core import Cloudtipsadp
-
+from cloudtipsadp.main import Cloudtipsadp
 
 __author__ = "SETTER"
 __email__ = 'lphp@mail.ru'
